@@ -42,9 +42,7 @@ end = struct
       | (key, value) :: xs ->
         if String.(last_key = key)
         then
-          if eq last_value value
-          then loop acc ~last_key ~last_value xs
-          else `Mismatch key
+          if eq last_value value then loop acc ~last_key ~last_value xs else `Mismatch key
         else loop ((key, value) :: acc) ~last_key:key ~last_value:value xs
     in
     function
@@ -303,8 +301,7 @@ module Canonical_digest : Canonical = struct
     let tuple l = Exp1.create (Tuple l)
 
     let poly_variant loc l =
-      Exp1.create
-        (Poly_variant (Sorted_table.create loc ~eq:(equal_option Exp1.equal) l))
+      Exp1.create (Poly_variant (Sorted_table.create loc ~eq:(equal_option Exp1.equal) l))
     ;;
 
     let var x = Exp1.create (Var x)
@@ -317,13 +314,7 @@ module Canonical_digest : Canonical = struct
   end
 end
 
-module Canonical_full : sig
-  type t [@@deriving compare, sexp]
-
-  include Canonical with type t := t
-
-  val to_string_hum : t -> string
-end = struct
+module Canonical_full = struct
   module CD = Create_digest
 
   module Exp1 = struct
@@ -396,11 +387,11 @@ end
 
 module Gid : sig
   (* unique group-id, used as key for Tenv below *)
-  type t [@@deriving compare, sexp_of]
+  type t [@@deriving compare, equal, sexp]
 
   val create : unit -> t
 end = struct
-  type t = int [@@deriving compare, sexp_of]
+  type t = int [@@deriving compare, equal, sexp]
 
   let r = ref 0
 
@@ -416,10 +407,10 @@ module Expression = struct
     [ `Constr of string * 't option
     | `Inherit of Location.t * 't
     ]
-  [@@deriving compare, sexp_of]
+  [@@deriving compare, equal, sexp]
 
   module Group : sig
-    type 'a t [@@deriving compare, sexp_of]
+    type 'a t [@@deriving compare, equal, sexp]
 
     val create : Location.t -> (Tid.t * Vid.t list * 'a) list -> 'a t
     val id : 'a t -> Gid.t
@@ -430,7 +421,7 @@ module Expression = struct
       ; loc : Location.t
       ; members : (Tid.t * (Vid.t list * 'a)) list
       }
-    [@@deriving compare, sexp_of]
+    [@@deriving compare, equal, sexp]
 
     let create loc trips =
       let gid = Gid.create () in
@@ -452,17 +443,23 @@ module Expression = struct
     ;;
   end
 
-  type t =
-    | Annotate of Uuid.t * t
-    | Base of Uuid.t * t list
-    | Record of (string * t) list
-    | Variant of (string * t list) list
-    | Tuple of t list
-    | Poly_variant of (Location.t * t poly_constr list)
-    | Var of (Location.t * Vid.t)
-    | Rec_app of Tid.t * t list
-    | Top_app of t Group.t * Tid.t * t list
-  [@@deriving variants, sexp_of]
+  module Stable = struct
+    module V1 = struct
+      type t =
+        | Annotate of Uuid.t * t
+        | Base of Uuid.t * t list
+        | Record of (string * t) list
+        | Variant of (string * t list) list
+        | Tuple of t list
+        | Poly_variant of (Location.t * t poly_constr list)
+        | Var of (Location.t * Vid.t)
+        | Rec_app of Tid.t * t list
+        | Top_app of t Group.t * Tid.t * t list
+      [@@deriving equal, sexp, variants]
+    end
+  end
+
+  include Stable.V1
 
   type group = t Group.t
 
@@ -662,8 +659,7 @@ module Evaluation (Canonical : Canonical) = struct
         eval group venv t >>= fun v -> return (Canonical.Create.annotate s v)
       | Base (s, ts) ->
         eval_list group venv ts >>= fun vs -> return (Canonical.Create.basetype s vs)
-      | Tuple ts ->
-        eval_list group venv ts >>= fun vs -> return (Canonical.Create.tuple vs)
+      | Tuple ts -> eval_list group venv ts >>= fun vs -> return (Canonical.Create.tuple vs)
       | Top_app (in_group, tid, args) ->
         eval_list group venv args
         >>= fun args ->
@@ -705,8 +701,7 @@ module Evaluation (Canonical : Canonical) = struct
       let venv = Venv.create (List.mapi formals ~f:(fun i x -> x, Canonical.Exp1.var i)) in
       eval group venv body >>= fun v -> return (Canonical.Create.define v)
 
-  and eval_app : group -> Tid.t -> _ Canonical.Exp1.t list -> _ Canonical.Exp1.t defining
-    =
+  and eval_app : group -> Tid.t -> _ Canonical.Exp1.t list -> _ Canonical.Exp1.t defining =
     fun group tid args ->
       let gid = Group.id group in
       let formals, body = Group.lookup group tid in
@@ -771,3 +766,9 @@ module For_typerep = struct
     | _ -> raise (Not_a_tuple t)
   ;;
 end
+
+module Expert = struct
+  module Sorted_table = Sorted_table
+  module Canonical_exp_constructor = Canonical_exp_constructor
+  module Canonical = Canonical
+end
